@@ -35,7 +35,11 @@ class SimpleRocks(object):
         self.closed = False
 
     def __contains__(self, key_):
-        self.db.contains()
+        try:
+            self[key_]
+            return True
+        except KeyError:
+            return False
 
     def __del__(self):
         if self.db is not None:
